==> adminer-2.3.2.tbz: www/adminer/adminer/lang/it.inc.php <==
<?php
$translations = array(
	'Login' => 'Autenticazione',
	'Logout successful.' => 'Uscita effettuata con successo.',
	'Invalid credentials.' => 'Credenziali non valide.',
	'Server' => 'Server',
	'Username' => 'Utente',
	'Password' => 'Password',
	'Select database' => 'Seleziona database',
	'Invalid database.' => 'Database non valido.',
	'Create new database' => 'Crea nuovo database',
	'Table has been dropped.' => 'Tabella eliminata.',
	'Table has been altered.' => 'Tabella modificata.',
	'Table has been created.' => 'Tabella creata.',
	'Alter table' => 'Modifica tabella',
	'Create table' => 'Crea tabella',
	'Table name' => 'Nome tabella',
	'engine' => 'motore',
	'collation' => 'collazione',
	'Column name' => 'Nome colonna',
	'Type' => 'Tipo',
	'Length' => 'Lunghezza',
	'Auto Increment' => 'Auto incremento',
	'Options' => 'Opzioni',
	'Save' => 'Salva',
	'Drop' => 'Elimina',
	'Database has been dropped.' => 'Database eliminato.',
	'Database has been created.' => 'Database creato.',
	'Database has been renamed.' => 'Database rinominato.',
	'Database has been altered.' => 'Database modificato.',
	'Alter database' => 'Modifica database',
	'Create database' => 'Crea database',
	'SQL command' => 'Comando SQL',
	'Dump' => 'Dump',
	'Logout' => 'Esci',
	'database' => 'database',
	'Use' => 'Usa',
	'No tables.' => 'No tabelle.',
	'select' => 'seleziona',
	'Create new table' => 'Crea nuova tabella',
	'Item has been deleted.' => 'Elemento eliminato.',
	'Item has been updated.' => 'Elemento aggiornato.',
	'Item has been inserted.' => 'Elemento inserito.',
	'Edit' => 'Modifica',
	'Insert' => 'Inserisci',
	'Save and insert next' => 'Salva e inserisci un altro',
	'Delete' => 'Elimina',
	'Database' => 'Database',
	'Routines' => 'Routine',
	'Indexes have been altered.' => 'Indici modificati.',
	'Indexes' => 'Indici',
	'Alter indexes' => 'Modifica indici',
	'Add next' => 'Aggiungi altro',
	'Language' => 'Lingua',
	'Select' => 'Seleziona',
	'New item' => 'Nuovo elemento',
	'Search' => 'Cerca',
	'Sort' => 'Ordina',
	'descending' => 'discendente',
	'Limit' => 'Limite',
	'No rows.' => 'Nessuna riga.',
	'Action' => 'Azione',
	'edit' => 'modifica',
	'Page' => 'Pagina',
	'Query executed OK, %d row(s) affected.' => array('Esecuzione della query OK, %d riga interessata.', 'Esecuzione della query OK, %d righe interessate.'),
	'Error in query' => 'Errore nella query',
	'Execute' => 'Esegui',
	'Table' => 'Tabella',
	'Foreign keys' => 'Chiavi esterne',
	'Triggers' => 'Trigger',
	'View' => 'Vedi',
	'Unable to select the table' => 'Selezione della tabella non riuscita',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF non valido. Reinvia la richiesta.',
	'Comment' => 'Commento',
	'Default values' => 'Valori predefiniti',
	'Show column comments' => 'Mostra i commenti delle colonne',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Nessun commando da eseguire.',
	'Unable to upload a file.' => 'Caricamento del file non riuscito.',
	'File upload' => 'Caricamento file',
	'File uploads are disabled.' => 'Caricamento file disabilitato.',
	'Routine has been called, %d row(s) affected.' => array('Routine chiamata, %d riga interessata.', 'Routine chiamata, %d righe interessate.'),
	'Call' => 'Chiama',
	'No MySQL extension' => 'Estensioni MySQL non presenti',
	'None of the supported PHP extensions (%s) are available.' => 'Nessuna delle estensioni PHP supportate (%s) disponibile.',
	'Session support must be enabled.' => 'Le sessioni devono essere abilitate.',
	'Session expired, please login again.' => 'Sessione scaduta, autenticarsi di nuovo.',
	'Text length' => 'Lunghezza testo',
	'Foreign key has been dropped.' => 'Foreign key eliminata.',
	'Foreign key has been altered.' => 'Foreign key modificata.',
	'Foreign key has been created.' => 'Foreign key creata.',
	'Foreign key' => 'Foreign key',
	'Target table' => 'Tabella obiettivo',
	'Change' => 'Cambia',
	'Source' => 'Sorgente',
	'Target' => 'Obiettivo',
	'Add column' => 'Aggiungi colonna',
	'Alter' => 'Modifica',
	'Add foreign key' => 'Aggiungi foreign key',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Tipo indice',
	'Column (length)' => 'Colonna (lunghezza)',
	'View has been dropped.' => 'Vista eliminata.',
	'View has been altered.' => 'Vista modificata.',
	'View has been created.' => 'Vista creata.',
	'Alter view' => 'Modifica vista',
	'Create view' => 'Crea vista',
	'Name' => 'Nome',
	'Process list' => 'Elenco processi',
	'%d process(es) have been killed.' => array('%d processo interrotto.', '%d processi interrotti.'),
	'Kill' => 'Interrompi',
	'Parameter name' => 'Nome parametro',
	'Database schema' => 'Schema database',
	'Create procedure' => 'Crea procedura',
	'Create function' => 'Crea funzione',
	'Routine has been dropped.' => 'Routine eliminata.',
	'Routine has been altered.' => 'Routine modificata.',
	'Routine has been created.' => 'Routine creata.',
	'Alter function' => 'Modifica funzione',
	'Alter procedure' => 'Modifica procedura',
	'Return type' => 'Return type',
	'Add trigger' => 'Aggiungi trigger',
	'Trigger has been dropped.' => 'Trigger eliminato.',
	'Trigger has been altered.' => 'Trigger modificato.',
	'Trigger has been created.' => 'Trigger creato.',
	'Alter trigger' => 'Modifica trigger',
	'Create trigger' => 'Crea trigger',
	'Time' => 'Orario',
	'Event' => 'Evento',
	'MySQL version: %s through PHP extension %s' => 'Versione MySQL: %s via estensione PHP %s',
	'%d row(s)' => array('%d riga', '%d righe'),
	'~ %s' => '~ %s',
	'Remove' => 'Rimuovi',
	'Are you sure?' => 'Sicuro?',
	'Privileges' => 'Privilegi',
	'Create user' => 'Crea utente',
	'User has been dropped.' => 'Utente eliminato.',
	'User has been altered.' => 'Utente modificato.',
	'User has been created.' => 'Utente creato.',
	'Hashed' => 'Hashed',
	'Column' => 'Colonna',
	'Routine' => 'Routine',
	'Grant' => 'Permetti',
	'Revoke' => 'Revoca',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Troppi dati via POST. Ridurre i dati o aumentare la direttiva di configurazione %s.',
	'Logged as: %s' => 'Autenticato come: %s',
	'Move up' => 'Sposta su',
	'Move down' => 'Sposta giu',
	'Functions' => 'Funzioni',
	'Aggregation' => 'Aggregazione',
	'Export' => 'Esporta',
	'Output' => 'Risultato',
	'open' => 'apri',
	'save' => 'salva',
	'Format' => 'Formato',
	'Tables' => 'Tabelle',
	'Data' => 'Dati',
	'Event has been dropped.' => 'Evento eliminato.',
	'Event has been altered.' => 'Evento modificato.',
	'Event has been created.' => 'Evento creato.',
	'Alter event' => 'Modifica evento',
	'Create event' => 'Crea evento',
	'Start' => 'Inizio',
	'End' => 'Fine',
	'Every' => 'Ogni',
	'Status' => 'Stato',
	'On completion preserve' => 'Al termine preservare',
	'Events' => 'Eventi',
	'Schedule' => 'Pianifica',
	'At given time' => 'A tempo prestabilito',
	'Save and continue edit' => 'Salva e continua',
	'original' => 'originale',
	'Tables have been truncated.' => 'Le tabelle sono state svuotate.',
	'Tables have been moved.' => 'Le tabelle sono state spostate.',
	'Tables have been dropped.' => 'Le tabelle sono state eliminate.',
	'Tables and views' => 'Tabelle e viste',
	'Engine' => 'Motore',
	'Collation' => 'Collazione',
	'Data Length' => 'Lunghezza dato',
	'Index Length' => 'Lunghezza indice',
	'Data Free' => 'Dati liberi',
	'Rows' => 'Righe',
	',' => '.',
	'Analyze' => 'Analizza',
	'Optimize' => 'Ottimizza',
	'Check' => 'Controlla',
	'Repair' => 'Ripara',
	'Truncate' => 'Svuota',
	'Move to other database' => 'Sposta in altro database',
	'Move' => 'Sposta',
	'%d item(s) have been affected.' => array('Il risultato consiste in %d elemento', 'Il risultato consiste in %d elementi'),
	'whole result' => 'intero risultato',
	'Clone' => 'Clona',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Troppi campi. Per favore aumentare %s e %s.',
	'Partition by' => 'Partiziona per',
	'Partitions' => 'Partizioni',
	'Partition name' => 'Nome partizione',
	'Values' => 'Valori',
	'%d row(s) have been imported.' => array('%d riga importata.','%d righe importate.'),
	'Show structure' => 'Struttura tabella',
	'(anywhere)' => '(ovunque)',
	'CSV Import' => 'Importa da CSV',
	'Import' => 'Importa',
	'Stop on error' => 'Stop su errore',
	'Select data' => 'Scegli tabella',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[yyyy]',
	'History' => 'Storico',
	'Variables' => 'Variabili',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Le colonne sorgente e destinazione devono essere dello stesso tipo e ci deve essere un indice sulla colonna di destinazione e sui dati referenziati.',
	'Relations' => 'Relazioni',
	'Run file' => 'Esegui file',
	'Clear' => 'Pulisci',
	'Maximum allowed file size is %sB.' => 'La dimensione massima del file è %sB.',
	'Numbers' => 'Numeri',
	'Date and time' => 'Data e ora',
	'Strings' => 'Stringhe',
	'Binary' => 'Binari',
	'Lists' => 'Liste',
	'Editor' => 'Editor',
	'E-mail' => 'E-mail',
	'From' => 'Da',
	'Subject' => 'Oggetto',
	'Send' => 'Invia',
	'%d e-mail(s) have been sent.' => array('%d e-mail inviata.','%d e-mail inviate.'),
	'Webserver file %s' => 'Webserver file %s',
	'File does not exist.' => 'Il file non esiste.',
	'%d in total' => '%d in totale',
	'Permanent login' => 'Login permanente',
);

==> adminer-3.1.0_1.tbz: www/adminer/adminer/lang/it.inc.php <==
<?php
$translations = array(
	'Login' => 'Autenticazione',
	'Logout successful.' => 'Uscita effettuata con successo.',
	'Invalid credentials.' => 'Credenziali non valide.',
	'Server' => 'Server',
	'Username' => 'Utente',
	'Password' => 'Password',
	'Select database' => 'Seleziona database',
	'Invalid database.' => 'Database non valido.',
	'Create new database' => 'Crea nuovo database',
	'Table has been dropped.' => 'Tabella eliminata.',
	'Table has been altered.' => 'Tabella modificata.',
	'Table has been created.' => 'Tabella creata.',
	'Alter table' => 'Modifica tabella',
	'Create table' => 'Crea tabella',
	'Table name' => 'Nome tabella',
	'engine' => 'motore',
	'collation' => 'collazione',
	'Column name' => 'Nome colonna',
	'Type' => 'Tipo',
	'Length' => 'Lunghezza',
	'Auto Increment' => 'Auto incremento',
	'Options' => 'Opzioni',
	'Save' => 'Salva',
	'Drop' => 'Elimina',
	'Database has been dropped.' => 'Database eliminato.',
	'Database has been created.' => 'Database creato.',
	'Database has been renamed.' => 'Database rinominato.',
	'Database has been altered.' => 'Database modificato.',
	'Alter database' => 'Modifica database',
	'Create database' => 'Crea database',
	'SQL command' => 'Comando SQL',
	'Dump' => 'Dump',
	'Logout' => 'Esci',
	'database' => 'database',
	'Use' => 'Usa',
	'No tables.' => 'No tabelle.',
	'select' => 'seleziona',
	'Create new table' => 'Crea nuova tabella',
	'Item has been deleted.' => 'Elemento eliminato.',
	'Item has been updated.' => 'Elemento aggiornato.',
	'Item%s has been inserted.' => 'Elemento%s inserito.',
	'Edit' => 'Modifica',
	'Insert' => 'Inserisci',
	'Save and insert next' => 'Salva e inserisci un altro',
	'Delete' => 'Elimina',
	'Database' => 'Database',
	'Routines' => 'Routine',
	'Indexes have been altered.' => 'Indici modificati.',
	'Indexes' => 'Indici',
	'Alter indexes' => 'Modifica indici',
	'Add next' => 'Aggiungi altro',
	'Language' => 'Lingua',
	'Select' => 'Seleziona',
	'New item' => 'Nuovo elemento',
	'Search' => 'Cerca',
	'Sort' => 'Ordina',
	'descending' => 'discendente',
	'Limit' => 'Limite',
	'No rows.' => 'Nessuna riga.',
	'Action' => 'Azione',
	'edit' => 'modifica',
	'Page' => 'Pagina',
	'Query executed OK, %d row(s) affected.' => array('Esecuzione della query OK, %d riga interessata.', 'Esecuzione della query OK, %d righe interessate.'),
	'Error in query' => 'Errore nella query',
	'Execute' => 'Esegui',
	'Table' => 'Tabella',
	'Foreign keys' => 'Chiavi esterne',
	'Triggers' => 'Trigger',
	'View' => 'Vedi',
	'Unable to select the table' => 'Selezione della tabella non riuscita',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF non valido. Reinvia la richiesta.',
	'Comment' => 'Commento',
	'Default values' => 'Valori predefiniti',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Nessun commando da eseguire.',
	'Unable to upload a file.' => 'Caricamento del file non riuscito.',
	'File upload' => 'Caricamento file',
	'File uploads are disabled.' => 'Caricamento file disabilitato.',
	'Routine has been called, %d row(s) affected.' => array('Routine chiamata, %d riga interessata.', 'Routine chiamata, %d righe interessate.'),
	'Call' => 'Chiama',
	'No extension' => 'Estensioni non presenti',
	'None of the supported PHP extensions (%s) are available.' => 'Nessuna delle estensioni PHP supportate (%s) disponibile.',
	'Session support must be enabled.' => 'Le sessioni devono essere abilitate.',
	'Session expired, please login again.' => 'Sessione scaduta, autenticarsi di nuovo.',
	'Text length' => 'Lunghezza testo',
	'Foreign key has been dropped.' => 'Foreign key eliminata.',
	'Foreign key has been altered.' => 'Foreign key modificata.',
	'Foreign key has been created.' => 'Foreign key creata.',
	'Foreign key' => 'Foreign key',
	'Target table' => 'Tabella obiettivo',
	'Change' => 'Cambia',
	'Source' => 'Sorgente',
	'Target' => 'Obiettivo',
	'Add column' => 'Aggiungi colonna',
	'Alter' => 'Modifica',
	'Add foreign key' => 'Aggiungi foreign key',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Tipo indice',
	'Column (length)' => 'Colonna (lunghezza)',
	'View has been dropped.' => 'Vista eliminata.',
	'View has been altered.' => 'Vista modificata.',
	'View has been created.' => 'Vista creata.',
	'Alter view' => 'Modifica vista',
	'Create view' => 'Crea vista',
	'Name' => 'Nome',
	'Process list' => 'Elenco processi',
	'%d process(es) have been killed.' => array('%d processo interrotto.', '%d processi interrotti.'),
	'Kill' => 'Interrompi',
	'Parameter name' => 'Nome parametro',
	'Database schema' => 'Schema database',
	'Create procedure' => 'Crea procedura',
	'Create function' => 'Crea funzione',
	'Routine has been dropped.' => 'Routine eliminata.',
	'Routine has been altered.' => 'Routine modificata.',
	'Routine has been created.' => 'Routine creata.',
	'Alter function' => 'Modifica funzione',
	'Alter procedure' => 'Modifica procedura',
	'Return type' => 'Return type',
	'Add trigger' => 'Aggiungi trigger',
	'Trigger has been dropped.' => 'Trigger eliminato.',
	'Trigger has been altered.' => 'Trigger modificato.',
	'Trigger has been created.' => 'Trigger creato.',
	'Alter trigger' => 'Modifica trigger',
	'Create trigger' => 'Crea trigger',
	'Time' => 'Orario',
	'Event' => 'Evento',
	'%s version: %s through PHP extension %s' => 'Versione %s: %s via estensione PHP %s',
	'%d row(s)' => array('%d riga', '%d righe'),
	'Remove' => 'Rimuovi',
	'Are you sure?' => 'Sicuro?',
	'Privileges' => 'Privilegi',
	'Create user' => 'Crea utente',
	'User has been dropped.' => 'Utente eliminato.',
	'User has been altered.' => 'Utente modificato.',
	'User has been created.' => 'Utente creato.',
	'Hashed' => 'Hashed',
	'Column' => 'Colonna',
	'Routine' => 'Routine',
	'Grant' => 'Permetti',
	'Revoke' => 'Revoca',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Troppi dati via POST. Ridurre i dati o aumentare la direttiva di configurazione %s.',
	'Logged as: %s' => 'Autenticato come: %s',
	'Move up' => 'Sposta su',
	'Move down' => 'Sposta giu',
	'Functions' => 'Funzioni',
	'Aggregation' => 'Aggregazione',
	'Export' => 'Esporta',
	'Output' => 'Risultato',
	'open' => 'apri',
	'save' => 'salva',
	'Format' => 'Formato',
	'Tables' => 'Tabelle',
	'Data' => 'Dati',
	'Event has been dropped.' => 'Evento eliminato.',
	'Event has been altered.' => 'Evento modificato.',
	'Event has been created.' => 'Evento creato.',
	'Alter event' => 'Modifica evento',
	'Create event' => 'Crea evento',
	'Start' => 'Inizio',
	'End' => 'Fine',
	'Every' => 'Ogni',
	'Status' => 'Stato',
	'On completion preserve' => 'Al termine preservare',
	'Events' => 'Eventi',
	'Schedule' => 'Pianifica',
	'At given time' => 'A tempo prestabilito',
	'Save and continue edit' => 'Salva e continua',
	'original' => 'originale',
	'Tables have been truncated.' => 'Le tabelle sono state svuotate.',
	'Tables have been moved.' => 'Le tabelle sono state spostate.',
	'Tables have been dropped.' => 'Le tabelle sono state eliminate.',
	'Tables and views' => 'Tabelle e viste',
	'Engine' => 'Motore',
	'Collation' => 'Collazione',
	'Data Length' => 'Lunghezza dato',
	'Index Length' => 'Lunghezza indice',
	'Data Free' => 'Dati liberi',
	'Rows' => 'Righe',
	',' => '.',
	'Analyze' => 'Analizza',
	'Optimize' => 'Ottimizza',
	'Check' => 'Controlla',
	'Repair' => 'Ripara',
	'Truncate' => 'Svuota',
	'Move to other database' => 'Sposta in altro database',
	'Move' => 'Sposta',
	'%d item(s) have been affected.' => array('Il risultato consiste in %d elemento.', 'Il risultato consiste in %d elementi.'),
	'whole result' => 'intero risultato',
	'Clone' => 'Clona',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Troppi campi. Per favore aumentare %s e %s.',
	'Partition by' => 'Partiziona per',
	'Partitions' => 'Partizioni',
	'Partition name' => 'Nome partizione',
	'Values' => 'Valori',
	'%d row(s) have been imported.' => array('%d riga importata.', '%d righe importate.'),
	'anywhere' => 'ovunque',
	'CSV Import' => 'Importa da CSV',
	'Import' => 'Importa',
	'Stop on error' => 'Stop su errore',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[yyyy]',
	'History' => 'Storico',
	'Variables' => 'Variabili',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Le colonne sorgente e destinazione devono essere dello stesso tipo e ci deve essere un indice sulla colonna di destinazione e sui dati referenziati.',
	'Relations' => 'Relazioni',
	'Run file' => 'Esegui file',
	'Clear' => 'Pulisci',
	'Maximum allowed file size is %sB.' => 'La dimensione massima del file è %sB.',
	'Numbers' => 'Numeri',
	'Date and time' => 'Data e ora',
	'Strings' => 'Stringhe',
	'Binary' => 'Binari',
	'Lists' => 'Liste',
	'Editor' => 'Editor',
	'E-mail' => 'E-mail',
	'From' => 'Da',
	'Subject' => 'Oggetto',
	'Send' => 'Invia',
	'%d e-mail(s) have been sent.' => array('%d e-mail inviata.', '%d e-mail inviate.'),
	'Webserver file %s' => 'Webserver file %s',
	'File does not exist.' => 'Il file non esiste.',
	'%d in total' => '%d in totale',
	'Permanent login' => 'Login permanente',
	'Databases have been dropped.' => 'Database eliminati.',
	'Search data in tables' => 'Cerca nelle tabelle',
	'schema' => 'schema',
	'Schema' => 'Schema',
	'Alter schema' => 'Modifica schema',
	'Create schema' => 'Crea schema',
	'Schema has been dropped.' => 'Schema eliminato.',
	'Schema has been created.' => 'Schema creato.',
	'Schema has been altered.' => 'Schema modificato.',
	'Sequences' => 'Sequenza',
	'Create sequence' => 'Crea sequenza',
	'Alter sequence' => 'Modifica sequenza',
	'Sequence has been dropped.' => 'Sequenza eliminata.',
	'Sequence has been created.' => 'Sequenza creata.',
	'Sequence has been altered.' => 'Sequenza modificata.',
	'User types' => 'Tipi definiti dall\'utente',
	'Create type' => 'Crea tipo definito dall\'utente',
	'Alter type' => 'Modifica tipo definito dall\'utente',
	'Type has been dropped.' => 'Tipo definito dall\'utente eliminato.',
	'Type has been created.' => 'Tipo definito dall\'utente creato.',
	'Double click on a value to modify it.' => 'Fai doppio click su un valore per modificarlo.',
	'Increase Text length to modify this value.' => 'Aumenta la Lunghezza del testo per modificare questo valore.',
	'Use edit link to modify this value.' => 'Usa il link modifica per modificare questo valore.',
	'last' => 'ultima',
	'From server' => 'Dal server',
	'System' => 'Sistema',
	'Select data' => 'Visualizza dati',
	'Show structure' => 'Visualizza struttura',
	'empty' => 'vuoto',
	'Network' => 'Rete',
	'Geometry' => 'Geometria',
	'File exists.' => 'Il file esiste già.',
	'Attachments' => 'Allegati',
	'%d query(s) executed OK.' => array('%d query eseguita con successo.', '%d query eseguite con successo.'),
	'Show only errors' => 'Mostra solo gli errori',
	'Last page' => 'Ultima pagina',
	'Refresh' => 'Aggiorna',
	'Invalid schema.' => 'Schema non valido.',
	'Please use one of the extensions %s.' => 'Usa una delle estensioni %s.',
	'now' => 'adesso',
	'ltr' => 'ltr',
);
